@@ -21,7 +21,7 @@ namespace {
 
   // 位置の取得
   QRect getPosition(const ThemeResource& resource,
-                     const QString& tag_name) {
+                    const std::string& tag_name) {
 
     return resource.offset.value(tag_name, QRect(0, 0, 0, 0));
   }
@@ -30,7 +30,7 @@ namespace {
   // 画像の描画
   void drawPixmap(QPainter& painter,
                   const ThemeResource& resource,
-                  const QString& tag_name,
+                  const std::string& tag_name,
                   const QRect& offset,
                   size_t scaling_percent,
                   qreal rotate_degree = 0,
@@ -141,7 +141,7 @@ namespace {
 void ClockPartsDraw::redraw(ThemeClockDraw* parent,
                             const ThemeResource& resource,
                             const QVector<QPoint>& digital_positions,
-                            size_t scaling_percent) {
+                            size_t scaling_percent, int sec_offset) {
 
   QPainter painter(parent);
   painter.setRenderHint(QPainter::SmoothPixmapTransform);
@@ -151,7 +151,8 @@ void ClockPartsDraw::redraw(ThemeClockDraw* parent,
   drawPixmap(painter, resource, "base/base_org", offset, scaling_percent);
 
   // 部品画像の描画
-  QTime time = QTime::currentTime();
+  QTime current_time = QTime::currentTime();
+  QTime time = current_time.addSecs(sec_offset);
   updateDigital(painter, resource, digital_positions,
                 time.hour(), time.minute(), time.second(),
                 scaling_percent);
