@@ -27,7 +27,7 @@ namespace ClockPartsDraw {
   extern void redraw(ThemeClockDraw* parent,
                      const ThemeResource& resource,
                      const QVector<QPoint>& digital_positions,
-                     size_t scaling_percent = 100);
+                     size_t scaling_percent = 100, int sec_offset = 0);
 };
 
 #endif /* !CLOCK_PARTS_DRAW_H */
