@@ -25,6 +25,9 @@ class ClockSettingDialog : public QDialog, private Ui::ClockSettingDialog {
   struct pImpl;
   std::auto_ptr<pImpl> pimpl;
 
+private slots:
+  void scalingSliderHandler(int value);
+
  public:
 
   /*!
@@ -34,6 +37,16 @@ class ClockSettingDialog : public QDialog, private Ui::ClockSettingDialog {
   */
   explicit ClockSettingDialog(QDialog* parent = 0);
   ~ClockSettingDialog(void);
+
+  /*!
+    \brief 拡大率のスライドバーを設定
+
+    \param value [i] スライドバーの値
+  */
+  void setScalingPercent(int value);
+
+signals:
+  void scalingValueChanged(int);
 };
 
 #endif /* !SETTING_DIALOG_FORM_H */
