@@ -31,20 +31,30 @@ struct ThemeClockWidget::pImpl {
   QString pre_theme_file_;
   QString theme_file_;
   QPoint drag_position_;
+  size_t scaling_percent_;
+  size_t pre_scaling_percent_;
 
   ClockSettingDialog setting_dialog_;
 
 
   pImpl(ThemeClockWidget* parent)
-    : draw_widget_(new ThemeClockDraw(parent)) {
+    : draw_widget_(new ThemeClockDraw(parent)),
+      scaling_percent_(100), pre_scaling_percent_(100) {
   }
 
   // フォームの初期化
   void initializeForm(ThemeClockWidget* parent) {
 
+    // アイコンを適用
+    parent->setWindowIcon(QIcon(":icons/qclock_icon"));
+
     // 時計の更新設定
     connect(&clock_timer_, SIGNAL(timeout()), parent, SLOT(redraw()));
 
+    // 拡大率の設定
+    connect(&setting_dialog_, SIGNAL(scalingValueChanged(int)),
+            parent, SLOT(changeScaling(int)));
+
     // 終了処理
     connect(draw_widget_, SIGNAL(quit()), parent, SLOT(close()));
 
@@ -85,7 +95,9 @@ struct ThemeClockWidget::pImpl {
       return true;
 
     } else if (loadThemeFile(pre_theme_file_, parent)) {
-      // 前回利用したテーマ
+      // 前回利用したテーマ。拡大率があれば、設定する
+      parent->changeScaling(pre_scaling_percent_);
+      setting_dialog_.setScalingPercent(scaling_percent_);
       return true;
 
     } else {
@@ -121,6 +133,8 @@ struct ThemeClockWidget::pImpl {
     QSettings settings("Hyakuren Soft LTD.", "qtmclock");
     pre_theme_file_ = settings.value("theme_file", "").toString();
 
+    pre_scaling_percent_ = settings.value("scaling_percent", 0).toInt();
+
     if (! position_specified) {
       // 位置が指定されてないときのみ、設定を反映させる
       QRect position = settings.value("geometry", parent->geometry()).toRect();
@@ -136,6 +150,8 @@ struct ThemeClockWidget::pImpl {
     QFileInfo fi(theme_file_);
     settings.setValue("theme_file", fi.absoluteFilePath());
 
+    settings.setValue("scaling_percent", scaling_percent_);
+
     QRect position = parent->geometry();
     QSize size = parent->size();
 
@@ -195,6 +211,7 @@ ThemeClockWidget::~ThemeClockWidget(void) {
 
 // 再描画
 void ThemeClockWidget::redraw(void) {
+
   pimpl->redraw(this);
 }
 
@@ -287,3 +304,12 @@ void ThemeClockWidget::configHandler(void) {
   pimpl->setting_dialog_.show();
   pimpl->setting_dialog_.raise();
 }
+
+
+void ThemeClockWidget::changeScaling(int percent) {
+
+  pimpl->scaling_percent_ = percent;
+
+  pimpl->draw_widget_->updateScalingPercent(percent);
+  resize(pimpl->draw_widget_->size());
+}
