@@ -90,6 +90,9 @@ public:
   ThemeClockWidget(const QString& theme_file, const bool position_specified,
                    QWidget* parent = 0);
   ~ThemeClockWidget(void);
+
+signals:
+  void close(void);
 };
 
 #endif /* !THEME_CLOCK_WIDGET_H */
