@@ -11,8 +11,8 @@
 */
 
 #include <QMap>
+#include <string>
 
-class QString;
 class QPixmap;
 class QRect;
 
@@ -22,9 +22,9 @@ class QRect;
 */
 class ThemeResource {
 public:
-  QMap<QString, QPixmap*> pixmap; //!< 画像
-  QMap<QString, QRect> offset;    //!< 位置文字
-  QMap<QString, QString> option;  //!< オプション文字
+  QMap<std::string, QPixmap*> pixmap; //!< 画像
+  QMap<std::string, QRect> offset;    //!< 位置
+  QMap<std::string, std::string> option;  //!< オプション
 };
 
 
@@ -35,6 +35,9 @@ public:
   \param tags [i] 配置情報リソース
 */
 extern void loadDigitalPosition(QVector<QPoint>& digital_positions,
-                                const QMap<QString, QString>& tags);
+                                const QMap<std::string, std::string>& tags);
+
+extern void loadDigitalPosition(QVector<QPoint>& digital_positions,
+                                QMap<std::string, QPoint>& parts_positions);
 
 #endif /* !THEME_RESOURCE_H */
