@@ -15,6 +15,7 @@
 #include <QGraphicsPixmapItem>
 #include <QShortcut>
 #include <QMessageBox>
+#include <QTimer>
 #include <cmath>
 #include "ThemeConfigWindow.h"
 #include "ArchiveConfig.h"
@@ -22,6 +23,8 @@
 #include "ReleaseDialog.h"
 #include "ReleaseDataFile.h"
 #include "ConvertStdStringPath.h"
+#include "ThemeClockDraw.h"
+#include "ThemeResource.h"
 
 using namespace qrk;
 
@@ -99,6 +102,10 @@ struct ThemeConfigWindow::pImpl {
   ReleaseDialog release_dialog_;
   std::string work_dir_;
 
+  ThemeClockDraw preview_draw_;
+
+  QTimer redraw_timer_;
+
   pImpl(void)
     : new_act_(NULL), open_act_(NULL), save_act_(NULL),
       archive_config_(NULL), setting_config_(NULL), save_ok_(false),
@@ -158,8 +165,19 @@ struct ThemeConfigWindow::pImpl {
     connect(&release_dialog_, SIGNAL(release(QString, QString)),
             parent, SLOT(releaseHandler(QString, QString)));
 
-    // 再生、停止
-    // !!! イベント接続
+    // プレビュー
+    connect(parent->play_button_, SIGNAL(clicked()),
+            parent, SLOT(previewClock()));
+
+    // プレビュー
+    connect(&redraw_timer_, SIGNAL(timeout()), parent, SLOT(previewRedraw()));
+    connect(&preview_draw_, SIGNAL(previewClose()),
+            parent, SLOT(previewCloseHandler()));
+
+    // 時刻オフセット
+    connect(parent->offset_slider_, SIGNAL(valueChanged(int)),
+            parent, SLOT(offsetUpdated(int)));
+    // !!!
   }
 
 
@@ -262,7 +280,7 @@ struct ThemeConfigWindow::pImpl {
 
     // 再生ボタン
     parent->play_button_->setEnabled(enable);
-    parent->offset_slidebar_->setEnabled(enable);
+    parent->offset_slider_->setEnabled(enable);
 
     // 編集用 Widget
     parent->groupbox_->setEnabled(enable);
@@ -731,6 +749,96 @@ struct ThemeConfigWindow::pImpl {
     updateItems();
     setSaveEnabled(parent, true);
   }
+
+
+  // オフセット位置の設定
+  void setOffset(QMap<std::string, QRect>& offset,
+                 const std::string& tag_name) {
+
+    QPixmap* pixmap = pixmaps_.value(tag_name, NULL);
+    if (! pixmap) {
+      // !!! 失敗はしないはずだが、一応
+      return;
+    }
+
+    const QSize size = pixmap->size();
+    const QPoint point = parts_positions_[tag_name];
+    offset.insert(tag_name, QRect(point.x(), point.y(),
+                                  size.width(), size.height()));
+  }
+
+
+  // Prevew の開始
+  void previewOpened(ThemeConfigWindow* parent) {
+
+    redraw_timer_.stop();
+
+    // テーマの読み出し
+    QVector<QPoint> digital_positions;
+    loadDigitalPosition(digital_positions, parts_positions_);
+
+    // オフセット位置の生成
+    QMap<std::string, QRect> offset;
+    setOffset(offset, "analog/hari_h");
+    setOffset(offset, "analog/hari_m");
+    setOffset(offset, "analog/hari_s");
+
+    // オプションタグの登録
+    QMap<std::string, std::string> option;
+    option.insert("analog/sec",
+                  parent->analog_checkbox_->isChecked() ? "on" : "off");
+    option.insert("digital/sec",
+                  parent->digital_checkbox_->isChecked() ? "on" : "off");
+    option.insert("digital/colon",
+                  parent->blink_checkbox_->isChecked() ? "on" : "off");
+
+    preview_draw_.loadThemeResource(pixmaps_,
+                                    offset ,digital_positions, option);
+
+    setPreviewEnabled(parent, true);
+
+    // ダイアログの表示
+    preview_draw_.show();
+    preview_draw_.raise();
+
+    redraw_timer_.start(1000);
+    redrawPreview(parent);
+
+    // ボタンアイコンの変更
+    QIcon stop_icon(":/icons/stop_icon");
+    parent->play_button_->setIcon(stop_icon);
+  }
+
+
+  // Preview の終了
+  void previewClosed(ThemeConfigWindow* parent) {
+
+    redraw_timer_.stop();
+    setPreviewEnabled(parent, false);
+
+    // ボタンアイコンの変更
+    QIcon stop_icon(":/icons/play_icon");
+    parent->play_button_->setIcon(stop_icon);
+  }
+
+
+  // プレビュー次のフォーム設定
+  void setPreviewEnabled(ThemeConfigWindow* parent, bool enable) {
+
+    parent->parts_view_->setEnabled(! enable);
+    parent->parts_tree_->setEnabled(! enable);
+    parent->center_checkbox_->setEnabled(! enable);
+
+    parent->offset_slider_->setEnabled(enable);
+  }
+
+
+  // プレビューの再描画
+  void redrawPreview(ThemeConfigWindow* parent) {
+
+    int sec_offset = parent->offset_slider_->value() * 60;
+    preview_draw_.redraw(sec_offset);
+  }
 };
 
 
@@ -798,6 +906,9 @@ void ThemeConfigWindow::closeEvent(QCloseEvent* event) {
 
   // !!! Qt 本の P66 のあたりを参考のこと
 
+  // サブウィンドウを閉じる
+  pimpl->preview_draw_.close();
+
   // !!! とりあえず、終了
   event->accept();
 }
@@ -806,6 +917,10 @@ void ThemeConfigWindow::closeEvent(QCloseEvent* event) {
 // 新規
 void ThemeConfigWindow::newFile(void) {
 
+  // プレビューを閉じる
+  pimpl->
+preview_draw_.close();
+
   // 空の名前でファイル読み出しを指示し、設定が空のオブジェクトを作成する
   pimpl->loadArchiveFile(this, "");
 }
@@ -820,6 +935,10 @@ void ThemeConfigWindow::openFile(void) {
                                  tr("archive list (*.txt)"));
 
   if (! fileName.isEmpty()) {
+
+    // プレビューを閉じる
+    pimpl->preview_draw_.close();
+
     // 日本語のパスを含む場合への対処
     fileName = toStdStringPath(fileName);
 
@@ -905,10 +1024,27 @@ void ThemeConfigWindow::releaseHandler(const QString& file,
 // プレビュー
 void ThemeConfigWindow::previewClock(void) {
 
-  // !!!
+  if (! pimpl->redraw_timer_.isActive()) {
+    pimpl->previewOpened(this);
+  } else {
+    pimpl->preview_draw_.close();
+    pimpl->previewClosed(this);
+  }
+}
 
-  // !!! ThemeClockWidget を呼び出して表示
-  // !!! 表示をどうやって消すのかは、不明
+
+// プレビューの再描画
+void ThemeConfigWindow::previewRedraw(void) {
+
+  pimpl->redrawPreview(this);
+}
+
+
+// プレビュー表示オフセットの変更
+void ThemeConfigWindow::offsetUpdated(int value) {
+  static_cast<void>(value);
+
+  pimpl->redrawPreview(this);
 }
 
 
@@ -918,7 +1054,8 @@ void ThemeConfigWindow::aboutApplication(void) {
   QMessageBox::about(this, tr("About qtmclock_config"),
                      tr("<h2>Qtmclock Config</h2>"
                         "<p>Theme making tool for Qtmclock.</p>"
-                        "<p>Report bugs to &lt;satofumi@users.sourceforge.jp&gt;</p>"));
+                        "<p>Report bugs to "
+                        "&lt;satofumi@users.sourceforge.jp&gt;</p>"));
 }
 
 
@@ -936,6 +1073,10 @@ void ThemeConfigWindow::blinkCheckHandler(bool checked) {
 
   pimpl->setting_config_->setValue("digital/colon", checked ? "on" : "off");
   pimpl->setSaveEnabled(this, true);
+
+  if (pimpl->redraw_timer_.isActive()) {
+    pimpl->previewOpened(this);
+  }
 }
 
 
@@ -945,15 +1086,23 @@ void ThemeConfigWindow::analogCheckHandler(bool checked) {
   pimpl->setting_config_->setValue("analog/sec", checked ? "on" : "off");
   pimpl->updateItems();
   pimpl->setSaveEnabled(this, true);
+
+  if (pimpl->redraw_timer_.isActive()) {
+    pimpl->previewOpened(this);
+  }
 }
 
 
-// 秒針を表示するか、の設定
+// デジタル文字の秒を表示するか、の設定
 void ThemeConfigWindow::digitalCheckHandler(bool checked) {
 
   pimpl->setting_config_->setValue("digital/sec", checked ? "on" : "off");
   pimpl->updateItems();
   pimpl->setSaveEnabled(this, true);
+
+  if (pimpl->redraw_timer_.isActive()) {
+    pimpl->previewOpened(this);
+  }
 }
 
 
@@ -1042,21 +1191,26 @@ void ThemeConfigWindow::updateHandlelr(void) {
 }
 
 
-// !!! slot
-// !!! ドラッグ & ドロップで画像ファイルを選択できるようにする
-// !!! 画像でなければ、実際には登録しない
+// プレビューのクローズイベント処理
+void ThemeConfigWindow::previewCloseHandler(void) {
 
-
-// 選択中の部品移動を行う
-// !!! slot
-
-
-// 編集中に再生
-// !!! slot
+  pimpl->previewClosed(this);
+}
 
 
 // 再生のオフセット時間を変更
 // !!!
 
 
+// !!! ドラッグ & ドロップで画像ファイルを選択できるようにする
+// !!! 画像でなければ、実際には登録しない
+// !!! slot
+
+
+// 選択中の部品移動を行う
+// !!! slot
+
+
+
+
 // !!! Qt Demo の 画像のパズルを参考に、部品配置を変更するあたりを実装する
