@@ -1,5 +1,13 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS><TS version="1.1" language="ja_JP">
+<context>
+    <name>QLabel</name>
+    <message>
+        <location filename="../qtmclock/ThemeClockDraw.cpp" line="54"/>
+        <source>Drop theme file in this form.</source>
+        <translation>テーマファイルを、このフォームにドロップして下さい.</translation>
+    </message>
+</context>
 <context>
     <name>ReleaseDialog</name>
     <message>
@@ -26,112 +34,112 @@
         <translation>Theme Config</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="183"/>
+        <location filename="ThemeConfigWindowForm.ui" line="187"/>
         <source>long hand</source>
         <translation>長針</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="160"/>
+        <location filename="ThemeConfigWindowForm.ui" line="164"/>
         <source>base</source>
         <translation>ベース</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="175"/>
+        <location filename="ThemeConfigWindowForm.ui" line="179"/>
         <source>short hand</source>
         <translation>短針</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="191"/>
+        <location filename="ThemeConfigWindowForm.ui" line="195"/>
         <source>second hand</source>
         <translation>秒針</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="200"/>
+        <location filename="ThemeConfigWindowForm.ui" line="204"/>
         <source>digital character</source>
         <translation>デジタル文字</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="355"/>
+        <location filename="ThemeConfigWindowForm.ui" line="359"/>
         <source>toolbar</source>
         <translation>ツールバー</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="207"/>
+        <location filename="ThemeConfigWindowForm.ui" line="211"/>
         <source>hour</source>
         <translation>時</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="231"/>
+        <location filename="ThemeConfigWindowForm.ui" line="235"/>
         <source>minute</source>
         <translation>分</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="247"/>
+        <location filename="ThemeConfigWindowForm.ui" line="251"/>
         <source>second</source>
         <translation>秒</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="263"/>
+        <location filename="ThemeConfigWindowForm.ui" line="267"/>
         <source>AM/PM</source>
         <translation>AM/PM</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="223"/>
+        <location filename="ThemeConfigWindowForm.ui" line="227"/>
         <source>colon</source>
         <translation>コロン</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="150"/>
+        <location filename="ThemeConfigWindowForm.ui" line="154"/>
         <source>Node</source>
         <translation>項目</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="155"/>
+        <location filename="ThemeConfigWindowForm.ui" line="159"/>
         <source>Value</source>
         <translation>値</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="373"/>
+        <location filename="ThemeConfigWindowForm.ui" line="377"/>
         <source>Ctrl+N</source>
         <translation>Ctrl+N</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindow.cpp" line="743"/>
+        <location filename="ThemeConfigWindow.cpp" line="851"/>
         <source>Create a new config file.</source>
         <translation>設定ファイルの新規作成.</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="385"/>
+        <location filename="ThemeConfigWindowForm.ui" line="389"/>
         <source>Ctrl+O</source>
         <translation>Ctrl+O</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindow.cpp" line="747"/>
+        <location filename="ThemeConfigWindow.cpp" line="855"/>
         <source>Open an exist config file.</source>
         <translation>設定ファイルを開く.</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="397"/>
+        <location filename="ThemeConfigWindowForm.ui" line="401"/>
         <source>Ctrl+S</source>
         <translation>Ctrl+S</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindow.cpp" line="751"/>
+        <location filename="ThemeConfigWindow.cpp" line="859"/>
         <source>Save the config file to disk.</source>
         <translation>設定ファイルの保存.</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="101"/>
+        <location filename="ThemeConfigWindowForm.ui" line="105"/>
         <source>hands&apos;s center are samve.</source>
         <translation>長針、短針、秒針の中心を揃える.</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="92"/>
+        <location filename="ThemeConfigWindowForm.ui" line="96"/>
         <source>Drawing Options</source>
         <translation>配置オプション</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="168"/>
+        <location filename="ThemeConfigWindowForm.ui" line="172"/>
         <source>analog parts</source>
         <translation>アナログ部品</translation>
     </message>
@@ -141,164 +149,159 @@
         <translation>再生 / 停止</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="57"/>
-        <source>Pause / Resume</source>
-        <translation>一時停止 / 再開</translation>
-    </message>
-    <message>
-        <location filename="ThemeConfigWindowForm.ui" line="308"/>
+        <location filename="ThemeConfigWindowForm.ui" line="312"/>
         <source>File (&amp;F)</source>
         <translation>ファイル (&amp;F)</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="321"/>
+        <location filename="ThemeConfigWindowForm.ui" line="325"/>
         <source>Edit (&amp;E)</source>
         <translation>編集 (&amp;E)</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="327"/>
+        <location filename="ThemeConfigWindowForm.ui" line="331"/>
         <source>Help (&amp;H)</source>
         <translation>ヘルプ (&amp;H)</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindow.cpp" line="742"/>
+        <location filename="ThemeConfigWindow.cpp" line="850"/>
         <source>New</source>
         <translation>新規作成</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindow.cpp" line="746"/>
+        <location filename="ThemeConfigWindow.cpp" line="854"/>
         <source>Open</source>
         <translation>開く</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindow.cpp" line="750"/>
+        <location filename="ThemeConfigWindow.cpp" line="858"/>
         <source>Save</source>
         <translation>保存</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="402"/>
+        <location filename="ThemeConfigWindowForm.ui" line="406"/>
         <source>Release (&amp;R)</source>
         <translation>リリース (&amp;R)</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="407"/>
+        <location filename="ThemeConfigWindowForm.ui" line="411"/>
         <source>Exit (&amp;Q)</source>
         <translation>終了 (&amp;Q)</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="410"/>
+        <location filename="ThemeConfigWindowForm.ui" line="414"/>
         <source>Ctrl+Q</source>
         <translation>Ctrl+Q</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="415"/>
+        <location filename="ThemeConfigWindowForm.ui" line="419"/>
         <source>Save as</source>
         <translation>名前を付けて保存</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="420"/>
+        <location filename="ThemeConfigWindowForm.ui" line="424"/>
         <source>Preview (&amp;R)</source>
         <translation>プレビュー (&amp;R)</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="423"/>
+        <location filename="ThemeConfigWindowForm.ui" line="427"/>
         <source>Ctrl+R</source>
         <translation>Ctrl+R</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="428"/>
+        <location filename="ThemeConfigWindowForm.ui" line="432"/>
         <source>About (&amp;A)</source>
         <translation>このアプリケーションについて (&amp;A)</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="214"/>
+        <location filename="ThemeConfigWindowForm.ui" line="218"/>
         <source>h2</source>
         <translation>位置 (1の位)</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="238"/>
+        <location filename="ThemeConfigWindowForm.ui" line="242"/>
         <source>m2</source>
         <translation>位置 (1 の位)</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="254"/>
+        <location filename="ThemeConfigWindowForm.ui" line="258"/>
         <source>s2</source>
         <translation>位置 (1の位)</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="111"/>
+        <location filename="ThemeConfigWindowForm.ui" line="115"/>
         <source>blink digital colon.</source>
         <translation>デジタル文字のコロン表示を点滅させる.</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="131"/>
+        <location filename="ThemeConfigWindowForm.ui" line="135"/>
         <source>show digital second.</source>
         <translation>デジタル文字の秒を表示する.</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindow.cpp" line="818"/>
+        <location filename="ThemeConfigWindow.cpp" line="933"/>
         <source>Open archive list file.</source>
         <translation>設定ファイルを開く.</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindow.cpp" line="856"/>
+        <location filename="ThemeConfigWindow.cpp" line="975"/>
         <source>archive list (*.txt)</source>
         <translation>設定ファイル (*.txt)</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindow.cpp" line="854"/>
+        <location filename="ThemeConfigWindow.cpp" line="973"/>
         <source>Save archive list file.</source>
         <translation>設定ファイルの保存.</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="370"/>
+        <location filename="ThemeConfigWindowForm.ui" line="374"/>
         <source>New (&amp;N)</source>
         <translation>新規作成 (&amp;N)</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="382"/>
+        <location filename="ThemeConfigWindowForm.ui" line="386"/>
         <source>Open (&amp;O)</source>
         <translation>開く (&amp;O)</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="394"/>
+        <location filename="ThemeConfigWindowForm.ui" line="398"/>
         <source>Save (&amp;S)</source>
         <translation>保存 (&amp;S)</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="277"/>
+        <location filename="ThemeConfigWindowForm.ui" line="281"/>
         <source>Parts image</source>
         <translation>部品画像の更新</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="287"/>
+        <location filename="ThemeConfigWindowForm.ui" line="291"/>
         <source>...</source>
         <translation>...</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="121"/>
+        <location filename="ThemeConfigWindowForm.ui" line="125"/>
         <source>show analog second.</source>
         <translation>秒針を表示する.</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindow.cpp" line="1032"/>
+        <location filename="ThemeConfigWindow.cpp" line="1181"/>
         <source>Open parts file.</source>
         <translation>部品ファイルを開く.</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindow.cpp" line="1034"/>
+        <location filename="ThemeConfigWindow.cpp" line="1183"/>
         <source>parts file (*.png)</source>
         <translation>部品ファイル (*.png)</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindow.cpp" line="918"/>
+        <location filename="ThemeConfigWindow.cpp" line="1054"/>
         <source>About qtmclock_config</source>
         <translation>qtmclock_config について</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindow.cpp" line="921"/>
+        <location filename="ThemeConfigWindow.cpp" line="1058"/>
         <source>&lt;h2&gt;Qtmclock Config&lt;/h2&gt;&lt;p&gt;Theme making tool for Qtmclock.&lt;/p&gt;&lt;p&gt;Report bugs to &amp;lt;satofumi@users.sourceforge.jp&amp;gt;&lt;/p&gt;</source>
-        <translation>&lt;h2&gt;Qtmclock Config&lt;/h2&gt;&lt;p&gt;Qtmclock 用のテーマ作成ツール&lt;/p&gt;&lt;p&gt;バグの報告先&amp;lt;satofumi@users.sourceforge.jp&amp;gt;&lt;/p&gt;</translation>
+        <translation>&lt;h2&gt;Qtmclock Config&lt;/h2&gt;&lt;p&gt;Qtmclock 用のテーマ作成ツール&lt;/p&gt;&lt;p&gt;バグの報告先 &amp;lt;satofumi@users.sourceforge.jp&amp;gt;&lt;/p&gt;</translation>
     </message>
 </context>
 </TS>
